Struct FreeLoanedPagesHolder
Source #[repr(C)]
pub struct FreeLoanedPagesHolder {
pub used_: bool,
pub __bindgen_padding_0: [u8; 7],
pub pages_: VmPageDoublyLinkedList,
pub waiters_: __BindgenOpaqueArray8<[u8; 8]>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.