Struct PageQueues
Source #[repr(C)]
pub struct PageQueues {Show 31 fields
pub list_lock_: __BindgenOpaqueArray8<[u8; 24]>,
pub lock_: __BindgenOpaqueArray8<[u8; 24]>,
pub aging_event_: *mut Event,
pub aging_disabled_: bool,
pub __bindgen_padding_0: [u8; 7],
pub last_age_time_: __BindgenOpaqueArray8<[u8; 8]>,
pub last_age_reason_: PageQueues_AgeReason,
pub active_ratio_triggered_: bool,
pub __bindgen_padding_1: [u8; 3],
pub mru_event_: AutounsignalEvent,
pub lru_event_: AutounsignalEvent,
pub lru_action_: PageQueues_LruAction,
pub __bindgen_padding_2: [u8; 4],
pub page_queues_: __BindgenOpaqueArray8<[u8; 128]>,
pub isolate_queues_: __BindgenOpaqueArray8<[u8; 16]>,
pub lru_gen_: __BindgenOpaqueArray8<[u8; 8]>,
pub mru_gen_: __BindgenOpaqueArray8<[u8; 8]>,
pub page_queue_counts_: __BindgenOpaqueArray8<[u8; 128]>,
pub lazy_active_ratio_aging_skips_: __BindgenOpaqueArray8<[u8; 8]>,
pub consecutive_skipped_sweeps_: u32,
pub shutdown_threads_: u8,
pub __bindgen_padding_3: [u8; 3],
pub mru_thread_: *mut c_void,
pub lru_thread_: *mut c_void,
pub debug_compressor_: __BindgenOpaqueArray8<[u8; 8]>,
pub min_mru_rotate_time_: i64,
pub max_mru_rotate_time_: i64,
pub zero_fork_is_reclaimable_: u8,
pub anonymous_is_reclaimable_: u8,
pub __bindgen_padding_4: [u8; 6],
pub active_ratio_multiplier_: i64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.