Struct PmmNode
Source #[repr(C, align(16))]
pub struct PmmNode {Show 37 fields
pub canary_: u32,
pub __bindgen_padding_0: [u8; 4],
pub lock_: __BindgenOpaqueArray8<[u8; 24]>,
pub arena_cumulative_size_: u64,
pub free_count_: __BindgenOpaqueArray8<[u8; 8]>,
pub free_loaned_count_: __BindgenOpaqueArray8<[u8; 8]>,
pub loaned_count_: __BindgenOpaqueArray8<[u8; 8]>,
pub loan_cancelled_count_: __BindgenOpaqueArray8<[u8; 8]>,
pub free_list_: VmPageDoublyLinkedList,
pub loaned_list_lock_: __BindgenOpaqueArray8<[u8; 24]>,
pub free_loaned_list_: VmPageDoublyLinkedList,
pub phys_handoff_temporary_list_: VmPageDoublyLinkedList,
pub phys_handoff_vmo_list_: VmPageDoublyLinkedList,
pub permanently_reserved_list_: VmPageDoublyLinkedList,
pub should_wait_: PmmNode_ShouldWaitState,
pub __bindgen_padding_1: [u8; 4],
pub should_wait_free_pages_level_: u64,
pub may_allocate_evt_: AutounsignalEvent,
pub alloc_failed_no_mem_: u8,
pub __bindgen_padding_2: [u8; 7],
pub first_alloc_failure_: PmmNode_AllocFailure,
pub mem_signal_: *mut Event,
pub mem_signal_lower_bound_: u64,
pub mem_signal_upper_bound_: u64,
pub page_queues_: PageQueues,
pub __bindgen_padding_3: [u8; 8],
pub evictor_: Evictor,
pub compression_lock_: __BindgenOpaqueArray8<[u8; 24]>,
pub page_compression_: __BindgenOpaqueArray8<[u8; 8]>,
pub free_fill_enabled_: u8,
pub all_free_pages_filled_: bool,
pub __bindgen_padding_4: [u8; 6],
pub checker_: PmmChecker,
pub random_should_wait_seed_: usize,
pub used_arena_count_: usize,
pub arenas_: [PmmArena; 16],
pub __bindgen_padding_5: [u8; 8],
}
phys_handoff_temporary_list_: VmPageDoublyLinkedListphys_handoff_vmo_list_: VmPageDoublyLinkedListrandom_should_wait_seed_: usize
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.